@@ -6,7 +6,7 @@ use Sjis;
 
 chomp(my @script = <DATA>);
 
-for my $perlbin (qw(perl55 perl58 perl510)) {
+for my $perlbin (qw(perl55 perl56 perl58 perl510)) {
     next unless `$perlbin -v` =~ /This is perl,/;
     print "perlbin=$perlbin\n";
 
